Module span

Module span 

Byte-based span primitives.

Structs

ByteRange
Half-open byte range, [start, end), in a source file or virtual source.
InvalidByteRange
Error returned when constructing a byte range with start > end.
SourceSpan
A byte range tied to the source it belongs to.